@@ -12,9 +12,15 @@ prepare()
     ln -s ..//.//./..///foo/ foo/foo
     port=`find_free_port`
     ../src/chirp_server -r $PWD/foo -p $port &
-    echo $! > $PID_FILE
-    echo $port > $PORT_FILE
-    exit 0
+    pid=$!
+
+    if ps ux | awk '{print $2}' | grep "^$pid$"; then
+	echo $port> $PORT_FILE
+	echo $pid > $PID_FILE
+	exit 0
+    else
+    	exit 1
+    fi
 }
 
 run()
