@@ -38,7 +38,10 @@ static int auth_ticket_assert(struct link *link, time_t stoptime)
 			char command[PATH_MAX * 2 + 4096];
 
 			/* load the digest */
-			sprintf(command, "openssl rsa -in '%s' -pubout 2> /dev/null | openssl md5", ticket);
+			/* WARNING: openssl is *very* bad at giving sensible output. Use the last
+			 * 32 non-space characters as the MD5 sum.
+			 */
+			sprintf(command, "openssl rsa -in '%s' -pubout 2> /dev/null | openssl md5 2> /dev/null | tr -d '[:space:]' | tail -c 32", ticket);
 			FILE *digestf = popen(command, "r");
 			if(full_fread(digestf, digest, DIGEST_LENGTH) < DIGEST_LENGTH) {
 				pclose(digestf);
