@@ -4,6 +4,7 @@ This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 #include "work_queue.h"
+#include "get_canonical_path.h"
 #include "int_sizes.h"
 #include "link.h"
 #include "debug.h"
@@ -33,6 +34,7 @@ See the file COPYING for details.
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 
 #define WORKER_STATE_INIT  0
 #define WORKER_STATE_READY 1
@@ -42,6 +44,7 @@ See the file COPYING for details.
 
 #define WORK_QUEUE_FILE 0
 #define WORK_QUEUE_BUFFER 1
+#define WORK_QUEUE_REMOTECMD 2
 
 #define TASK_STATUS_INITIALIZING 0
 #define TASK_STATUS_SENDING_INPUT 1
@@ -438,22 +441,49 @@ static int get_output_files(struct work_queue_task *t, struct work_queue_worker
 	if(t->output_files) {
 		list_first_item(t->output_files);
 		while((tf = list_next_item(t->output_files))) {
-			open_time = timestamp_get();
-			get_output_item(tf->remote_name, (char *) tf->payload, q, w, received_items, &total_bytes);
-			close_time = timestamp_get();
-			if(t->result & WORK_QUEUE_RESULT_OUTPUT_FAIL) {
-				return 0;
+			if(tf->flags & WORK_QUEUE_THIRDPUT) {
+
+				debug(D_WQ, "thirdputting %s as %s", tf->remote_name, tf->payload);
+
+				if(!strcmp(tf->remote_name, tf->payload)) {
+					debug(D_WQ, "output file %s already on shared filesystem", tf->remote_name);
+					tf->flags |= WORK_QUEUE_PREEXIST;
+				} else {
+					char thirdput_result[WORK_QUEUE_LINE_MAX];
+					debug(D_WQ, "putting %s from %s (%s) to shared filesystem from %s", tf->remote_name, w->hostname, w->addrport, tf->payload);
+					open_time = timestamp_get();
+					link_putfstring(w->link, "thirdput %d %s %s\n", time(0) + short_timeout, WORK_QUEUE_FS_PATH, tf->remote_name, tf->payload);
+					link_readline(w->link, thirdput_result, WORK_QUEUE_LINE_MAX, time(0) + short_timeout);
+					close_time = timestamp_get();
+					sum_time += (close_time - open_time);
+				}
+			} else if(tf->type == WORK_QUEUE_REMOTECMD) {
+				char thirdput_result[WORK_QUEUE_LINE_MAX];
+				debug(D_WQ, "putting %s from %s (%s) to remote filesystem using %s", tf->remote_name, w->hostname, w->addrport, tf->payload);
+				open_time = timestamp_get();
+				link_putfstring(w->link, "thirdput %d %s %s\n", time(0) + short_timeout, WORK_QUEUE_FS_CMD, tf->remote_name, tf->payload);
+				link_readline(w->link, thirdput_result, WORK_QUEUE_LINE_MAX, time(0) + short_timeout);
+				close_time = timestamp_get();
+				sum_time += (close_time - open_time);
+			} else {
+
+				open_time = timestamp_get();
+				get_output_item(tf->remote_name, (char *) tf->payload, q, w, received_items, &total_bytes);
+				close_time = timestamp_get();
+				if(t->result & WORK_QUEUE_RESULT_OUTPUT_FAIL) {
+					return 0;
+				}
+				if(total_bytes) {
+					sum_time = close_time - open_time;
+					q->total_bytes_received += total_bytes;
+					q->total_receive_time += sum_time;
+					t->total_bytes_transferred += total_bytes;
+					t->total_transfer_time += sum_time;
+					w->total_bytes_transferred += total_bytes;
+					w->total_transfer_time += sum_time;
+				}
+				total_bytes = 0;
 			}
-			if(total_bytes) {
-				sum_time = close_time - open_time;
-				q->total_bytes_received += total_bytes;
-				q->total_receive_time += sum_time;
-				t->total_bytes_transferred += total_bytes;
-				t->total_transfer_time += sum_time;
-				w->total_bytes_transferred += total_bytes;
-				w->total_transfer_time += sum_time;
-			}
-			total_bytes = 0;
 
 
 			// Add the output item to the hash table if its cacheable
@@ -493,7 +523,7 @@ static void delete_uncacheable_files(struct work_queue_task *t, struct work_queu
 	if(t->input_files) {
 		list_first_item(t->input_files);
 		while((tf = list_next_item(t->input_files))) {
-			if(!(tf->flags & WORK_QUEUE_CACHE)) {
+			if(!(tf->flags & WORK_QUEUE_CACHE) && !(tf->flags & WORK_QUEUE_PREEXIST)) {
 				debug(D_WQ, "%s (%s) unlink %s", w->hostname, w->addrport, tf->remote_name);
 				link_putfstring(w->link, "unlink %s\n", time(0) + short_timeout, tf->remote_name);
 			}
@@ -503,7 +533,7 @@ static void delete_uncacheable_files(struct work_queue_task *t, struct work_queu
 	if(t->output_files) {
 		list_first_item(t->output_files);
 		while((tf = list_next_item(t->output_files))) {
-			if(!(tf->flags & WORK_QUEUE_CACHE)) {
+			if(!(tf->flags & WORK_QUEUE_CACHE) && !(tf->flags & WORK_QUEUE_PREEXIST)) {
 				debug(D_WQ, "%s (%s) unlink %s", w->hostname, w->addrport, tf->remote_name);
 				link_putfstring(w->link, "unlink %s\n", time(0) + short_timeout, tf->remote_name);
 			}
@@ -831,12 +861,35 @@ static int send_input_files(struct work_queue_task *t, struct work_queue_worker
 					goto failure;
 				total_bytes += actual;
 				sum_time += (close_time - open_time);
-			} else {
+			} else if(tf->type == WORK_QUEUE_REMOTECMD) {
+				debug(D_WQ, "%s (%s) needs %s from remote filesystem using %s", w->hostname, w->addrport, tf->remote_name, tf->payload);
 				open_time = timestamp_get();
-				if(!put_file(tf, q, w, &total_bytes))
-					goto failure;
+				link_putfstring(w->link, "thirdget %d %s %s\n", time(0) + short_timeout, WORK_QUEUE_FS_CMD, tf->remote_name, tf->payload);
 				close_time = timestamp_get();
 				sum_time += (close_time - open_time);
+			} else {
+				if(tf->flags & WORK_QUEUE_THIRDGET) {
+					debug(D_WQ, "%s (%s) needs %s from shared filesystem as %s", w->hostname, w->addrport, tf->payload, tf->remote_name);
+
+					if(!strcmp(tf->remote_name, tf->payload)) {
+						tf->flags |= WORK_QUEUE_PREEXIST;
+					} else {
+						open_time = timestamp_get();
+						if(tf->flags & WORK_QUEUE_SYMLINK) {
+							link_putfstring(w->link, "thirdget %d %s %s\n", time(0) + short_timeout, WORK_QUEUE_FS_SYMLINK, tf->remote_name, tf->payload);
+						} else {
+							link_putfstring(w->link, "thirdget %d %s %s\n", time(0) + short_timeout, WORK_QUEUE_FS_PATH, tf->remote_name, tf->payload);
+						}
+						close_time = timestamp_get();
+						sum_time += (close_time - open_time);
+					}
+				} else {				
+					open_time = timestamp_get();
+					if(!put_file(tf, q, w, &total_bytes))
+						goto failure;
+					close_time = timestamp_get();
+					sum_time += (close_time - open_time);
+				}
 			}
 		}
 		t->total_bytes_transferred += total_bytes;
@@ -927,6 +980,39 @@ struct work_queue_worker *find_worker_by_fcfs(struct work_queue *q)
 	return best_worker;
 }
 
+struct work_queue_worker *find_worker_by_random( struct work_queue *q )
+{
+        char *key;
+        struct work_queue_worker *w;
+        struct work_queue_worker *best_worker = 0;
+	struct work_queue_stats qs;
+	int num_workers_ready;
+	int random_ready_worker, ready_worker_count = 1;
+
+	srand(time(0));
+        
+	work_queue_get_stats(q, &qs);
+	num_workers_ready = qs.workers_ready;
+
+	if (num_workers_ready > 0) {
+		random_ready_worker = (rand() % num_workers_ready) + 1;
+	} else { 	
+  		random_ready_worker = 0;
+        }     
+
+        hash_table_firstkey(q->worker_table);
+        while(hash_table_nextkey(q->worker_table,&key,(void**)&w)) {
+                if(w->state==WORKER_STATE_READY && ready_worker_count==random_ready_worker) {
+			return w;
+		}
+		if (w->state==WORKER_STATE_READY){
+			ready_worker_count++;
+		}
+	}
+
+        return best_worker;
+}
+
 struct work_queue_worker *find_worker_by_time(struct work_queue *q)
 {
 	char *key;
@@ -968,6 +1054,8 @@ struct work_queue_worker *find_best_worker(struct work_queue *q, struct work_que
 		return find_worker_by_files(q, t);
 	case WORK_QUEUE_SCHEDULE_TIME:
 		return find_worker_by_time(q);
+	case WORK_QUEUE_SCHEDULE_RAND:
+		return find_worker_by_random(q);
 	case WORK_QUEUE_SCHEDULE_FCFS:
 	default:
 		return find_worker_by_fcfs(q);
@@ -1381,6 +1469,22 @@ void work_queue_task_specify_buffer(struct work_queue_task *t, const char *data,
 	list_push_tail(t->input_files, tf);
 }
 
+void work_queue_task_specify_file_command(struct work_queue_task *t, const char *remote_name, const char *cmd, int type, int flags)
+{
+	struct work_queue_file *tf = malloc(sizeof(struct work_queue_file));
+	tf->type = WORK_QUEUE_REMOTECMD;
+	tf->flags = flags;
+	tf->length = strlen(cmd);
+	tf->payload = strdup(cmd);
+	tf->remote_name = strdup(remote_name);
+
+	if(type == WORK_QUEUE_INPUT) {
+		list_push_tail(t->input_files, tf);
+	} else {
+		list_push_tail(t->output_files, tf);
+	}
+}
+
 void work_queue_task_specify_output_file(struct work_queue_task *t, const char *rname, const char *fname)
 {
 	return work_queue_task_specify_file(t, fname, rname, WORK_QUEUE_OUTPUT, WORK_QUEUE_CACHE);
