@@ -56,6 +56,7 @@ static struct batch_queue *remote_queue = 0;
 static char *project = NULL;
 static int priority = 0;
 static int port = 0;
+static int output_len_check = 0;
 
 typedef enum {
 	DAG_NODE_STATE_WAITING=0,
@@ -163,17 +164,14 @@ int dag_estimate_nodes_needed(struct dag *d, int actual_max)
 
 void dag_show_input_files(struct dag *d)
 {
-	struct dag_node *n,*m,*tmp;
+	struct dag_node *n,*tmp;
 	struct dag_file *f;
-	int nodeid;
 	struct hash_table *ih;
 	char *key;
 	void *value;
 
 	ih = hash_table_create(0,0);
 	for(n=d->nodes;n;n=n->next) {
-		nodeid = -1;
-		m = 0;
 		// for each source file, see if it is a target file of another node
 		for(f=n->source_files;f;f=f->next) {
 			// d->file_table contains all target files
@@ -1242,6 +1240,8 @@ void dag_node_complete( struct dag *d, struct dag_node *n, struct batch_job_info
 	struct dag_file *f;
 	int job_failed = 0;
 
+	struct stat stat_info;
+
 	if(n->state!=DAG_NODE_STATE_RUNNING) return;
 
 	if(n->local_job) {
@@ -1249,13 +1249,22 @@ void dag_node_complete( struct dag *d, struct dag_node *n, struct batch_job_info
 	} else {
 		d->remote_jobs_running--;
 	}
-
+	
 	if(info->exited_normally && info->exit_code==0) {
 		for(f=n->target_files;f;f=f->next) {
 			if(access(f->filename,R_OK)!=0) {
 				fprintf(stderr,"makeflow: %s did not create file %s\n",n->command,f->filename);
 				job_failed=1;
-			}
+			} else {
+				if (output_len_check){
+					if (stat(f->filename,&stat_info)==0){
+						if (stat_info.st_size<=0){
+							fprintf(stderr,"makeflow: %s created a file of length %ld\n",n->command,(long)stat_info.st_size);
+		                                	job_failed=1;
+						}
+					}
+				}
+			}	
 		}
 	} else {
 		if(info->exited_normally) {
@@ -1428,6 +1437,7 @@ static void show_help(const char *cmd)
 	printf(" -d <subsystem> Enable debugging for this subsystem\n");
 	printf(" -o <file>      Send debugging to this file.\n");
 	printf(" -K             Preserve (i.e., do not clean) intermediate symbolic links\n");
+	printf(" -z             Force failure on zero-length output files \n");
 	printf(" -v             Show version string\n");
 	printf(" -h             Show this help screen\n");
 	
@@ -1453,7 +1463,7 @@ int main( int argc, char *argv[] )
 
 	debug_config(argv[0]);
 
-	while((c = getopt(argc, argv, "aAB:cCd:DeF:GhiIj:J:kKl:L:N:o:Op:P:r:RS:T:vw:W:")) != (char) -1) {
+	while((c = getopt(argc, argv, "aAB:cC:d:DeF:GhiIj:J:kKl:L:N:o:Op:P:r:RS:T:vw:W:z")) != (char) -1) {
 		switch (c) {
 		case 'A':
 			skip_afs_check = 1;
@@ -1573,6 +1583,9 @@ int main( int argc, char *argv[] )
 		case 'K':
 			preserve_symlinks = 1;
 			break;
+		case 'z':
+			output_len_check = 1;
+			break;
 		default:
 			show_help(argv[0]);
 			return 1;
