@@ -1501,14 +1501,6 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 			}
 			break;
 
-		case SYSCALL64_fchmod:
-			if(entering) {
-				p->syscall_result = pfs_fchmod(args[0],args[1]);
-				if(p->syscall_result<0) p->syscall_result = -errno;
-				divert_to_dummy(p,p->syscall_result);
-			}
-			break;
-
 		case SYSCALL64_fchown:
 			if(entering) {
 				p->syscall_result = pfs_fchown(args[0],args[1],args[2]);
@@ -2075,6 +2067,135 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 			}
 			break;
 
+		case SYSCALL64_openat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_openat(args[0],path,args[2],args[3]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_mkdirat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_mkdirat(args[0],path,args[2]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_mknodat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_mknodat(args[0],path,args[2],args[3]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_fchownat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_fchownat(args[0],path,args[2],args[3],args[4]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_futimesat:
+			if(entering) {
+				struct timeval times[2];
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				if(args[2]) {
+					tracer_copy_in(p->tracer,times,(void*)args[2],sizeof(times));
+				} else {
+					gettimeofday(&times[0],0);
+					times[1] = times[0];
+				}
+				p->syscall_result = pfs_futimesat(args[0],path,times);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_newfstatat:
+			if(entering) {
+				struct pfs_stat lbuf;
+				struct pfs_kernel_stat kbuf;
+
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_fstatat(args[0],path,&lbuf,args[3]);
+				if(p->syscall_result<0) {
+					p->syscall_result = -errno;
+				} else {
+					COPY_STAT(lbuf,kbuf);
+					tracer_copy_out(p->tracer,&kbuf,(void*)args[1],sizeof(kbuf));
+				}
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_unlinkat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_unlinkat(args[0],path,args[2]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_renameat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				tracer_copy_in_string(p->tracer,path2,(void*)args[3],sizeof(path2));
+				p->syscall_result = pfs_renameat(args[0],path,args[2],path2);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+
+			break;
+		case SYSCALL64_linkat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				tracer_copy_in_string(p->tracer,path2,(void*)args[3],sizeof(path2));
+				p->syscall_result = pfs_linkat(args[0],path,args[2],path2,args[4]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_symlinkat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[0],sizeof(path));
+				tracer_copy_in_string(p->tracer,path2,(void*)args[2],sizeof(path2));
+				p->syscall_result = pfs_symlinkat(path,args[1],path2);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_readlinkat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_readlinkat(args[0],path,path2,sizeof(path2));
+				if(p->syscall_result<0) {
+					p->syscall_result = -errno;
+				} else {
+					tracer_copy_out(p->tracer,path2,(void*)args[2],p->syscall_result);
+				}
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
+
+		case SYSCALL64_fchmodat:
+			if(entering) {
+				tracer_copy_in_string(p->tracer,path,(void*)args[1],sizeof(path));
+				p->syscall_result = pfs_fchmodat(args[0],path,args[2],args[3]);
+				if(p->syscall_result<0) p->syscall_result = -errno;
+				divert_to_dummy(p,p->syscall_result);
+			}
+			break;
 
 		case SYSCALL64_uname:
 			if(pfs_false_uname) {
@@ -2309,6 +2430,10 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 
 				p->syscall_result = pfs_copyfile(source,target);
 
+				if(p->syscall_result<0) {
+					p->syscall_result = -errno;
+				}
+
 				divert_to_dummy(p,p->syscall_result);
 			}
 			break;
@@ -2320,7 +2445,10 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 				p->syscall_result = pfs_md5(path,(unsigned char*)digest);
 				if(p->syscall_result>=0) {
 					tracer_copy_out(p->tracer,digest,(void*)args[1],sizeof(digest));
+				} else {
+					p->syscall_result = -errno;
 				}
+
 				divert_to_dummy(p,p->syscall_result);
 			}
 			break;
