@@ -164,6 +164,25 @@ void pfs_table::complete_path( const char *short_path, char *full_path )
         }
 }
 
+/*
+Complete a path, starting with this fd assumed to be a directory.
+*/
+
+void pfs_table::complete_at_path( int dirfd, const char *path, char *full_path )
+{
+	if(path[0]=='/') {
+		strcpy(full_path,path);
+	} else {
+		if(dirfd==AT_FDCWD) {
+			sprintf(full_path,"%s/%s",working_dir,path);
+		} else {
+			get_full_name(dirfd,full_path);
+			strcat(full_path,"/");
+			strcat(full_path,path);
+		}
+	}
+}
+
 void pfs_table::follow_symlink( struct pfs_name *pname, int depth )
 {
 	char link_target[PFS_PATH_MAX];
@@ -1567,10 +1586,10 @@ int pfs_table::locate( const char *n, char *buf, int length )
 }
 
 
-int pfs_table::copyfile( const char *source, const char *target )
+pfs_ssize_t pfs_table::copyfile( const char *source, const char *target )
 {
 	pfs_name psource, ptarget;
-	int result;
+	pfs_ssize_t result;
 
 	if(!pfs_enable_small_file_optimizations) {
 		errno = ENOSYS;
@@ -1599,12 +1618,12 @@ int pfs_table::copyfile( const char *source, const char *target )
 	return result;
 }
 
-int pfs_table::copyfile_slow( const char *source, const char *target )
+pfs_ssize_t pfs_table::copyfile_slow( const char *source, const char *target )
 {
 	pfs_file *sourcefile;
 	pfs_file *targetfile;
 	pfs_stat info;
-	pfs_off_t total, ractual, wactual;
+	pfs_ssize_t total, ractual, wactual;
 	void *buffer;
 	int buffer_size = pfs_service_get_block_size();
 	int result;
